@@ -5,6 +5,7 @@
 from typing import Mapping
 
 from bioversions.utils import Getter, VersionType, get_soup
+import bioregistry
 
 __all__ = [
     "KEGGGetter",
@@ -16,10 +17,10 @@ URL = "https://www.kegg.jp/kegg/docs/relnote.html"
 class KEGGGetter(Getter):
     """A getter for KEGG."""
 
-    bioregistry_id = "kegg.pathway"
     name = "KEGG"
     date_fmt = "%B %d, %Y"
     version_type = VersionType.semver_minor
+    collection = ["kegg", *bioregistry.get_has_parts("kegg")]
 
     def get(self) -> Mapping[str, str]:
         """Get the latest KEGG version number."""
