@@ -6,7 +6,7 @@ import datetime
 import enum
 import ftplib
 import os
-from typing import Any, ClassVar, Mapping, Optional, Union
+from typing import Any, ClassVar, List, Mapping, Optional, Union
 
 import bioregistry
 import pydantic
@@ -47,9 +47,23 @@ def norm(s: str) -> str:
     return s.lower().replace(" ", "").replace("-", "").replace(".", "")
 
 
-def get_soup(url: str, verify: bool = True) -> BeautifulSoup:
-    """Get a beautiful soup parsed version of the given web page."""
-    res = requests.get(url, verify=verify)
+def get_soup(
+    url: str, verify: bool = True, timeout: Optional[int] = None, user_agent: Optional[str] = None
+) -> BeautifulSoup:
+    """Get a beautiful soup parsed version of the given web page.
+
+    :param url: The URL to download and parse with BeautifulSoup
+    :param verify: Should SSL be used? This is almost always true,
+        except for Ensembl, which makes a big pain
+    :param timeout: How many integer seconds to wait for a response?
+        Defaults to 15 if none given.
+    :param user_agent: A custom user-agent to set, e.g., to avoid anti-crawling mechanisms
+    :returns: A BeautifulSoup object
+    """
+    headers = {}
+    if user_agent:
+        headers["User-Agent"] = user_agent
+    res = requests.get(url, verify=verify, timeout=timeout or 15, headers=headers)
     soup = BeautifulSoup(res.text, features="html.parser")
     return soup
 
@@ -178,6 +192,9 @@ class Getter(metaclass=MetaGetter):
     date: ClassVar[str]
     homepage: ClassVar[str]
 
+    #: Prefixes this getter works for
+    collection: ClassVar[Optional[List[str]]] = None
+
     def get(self) -> Union[str, Mapping[str, str], datetime.datetime]:
         """Get the latest of this database."""
         raise NotImplementedError
@@ -262,7 +279,7 @@ class OBOFoundryGetter(Getter):
 
     def get(self) -> str:
         """Get the OBO version."""
-        url = f"http://purl.obolibrary.org/obo/{self.key}.obo"
+        url = f"https://purl.obolibrary.org/obo/{self.key}.obo"
         return self.process(get_obo_version(url))
 
     def process(self, version: str) -> str:
